Bombardier FAQ — Bombardier v1.00 documentation

### Navigation

- index
- next |
- previous |
- Bombardier v1.00 documentation »
- Bombardier documentation contents »

# Bombardier FAQ

- FAQ: General
  - Why does this project exist?
  - What does “Bombardier” mean, and how do you pronounce it?
  - What platforms does Bombardier run on?
  - Is Bombardier stable?
  - Who’s behind this?
- FAQ: Installation
  - How do I get started?
  - Can I use Bombardier with Python 3?

### Navigation

- index
- next |
- previous |
- Bombardier v1.00 documentation »
- Bombardier documentation contents »